@@ -45,13 +45,12 @@ typedef struct
   GtkWidget *infobar_vbox;
   GtkWidget *passphrase_warning_infobar;
 
-  GtkWidget *configure_checkbutton;
+  GtkWidget *reset_button;
   GtkWidget *grid;
 
   GtkWidget *name_entry;
   GtkWidget *options_entry;
-  GtkWidget *noauto_checkbutton;
-  GtkWidget *nofail_checkbutton;
+  GtkWidget *neg_noauto_checkbutton;
   GtkWidget *auth_checkbutton;
   GtkWidget *passphrase_label;
   GtkWidget *passphrase_entry;
@@ -82,7 +81,6 @@ static void
 update (CrypttabDialogData *data,
         GtkWidget          *widget)
 {
-  gboolean ui_configured;
   const gchar *ui_name;
   const gchar *ui_options;
   const gchar *ui_passphrase_contents;
@@ -112,7 +110,6 @@ update (CrypttabDialogData *data,
       passphrase_contents = "";
     }
 
-  ui_configured = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->configure_checkbutton));
   ui_name = gtk_entry_get_text (GTK_ENTRY (data->name_entry));
   ui_options = gtk_entry_get_text (GTK_ENTRY (data->options_entry));
   ui_passphrase_contents = gtk_entry_get_text (GTK_ENTRY (data->passphrase_entry));
@@ -156,26 +153,17 @@ update (CrypttabDialogData *data,
   g_free (s);
 
   g_object_freeze_notify (G_OBJECT (data->options_entry));
-  gdu_options_update_check_option (data->options_entry, "noauto", widget, data->noauto_checkbutton, FALSE);
-  gdu_options_update_check_option (data->options_entry, "nofail", widget, data->nofail_checkbutton, FALSE);
-  gdu_options_update_check_option (data->options_entry, "x-udisks-auth", widget, data->auth_checkbutton, FALSE);
+  gdu_options_update_check_option (data->options_entry, "noauto", widget, data->neg_noauto_checkbutton, TRUE, FALSE);
+  gdu_options_update_check_option (data->options_entry, "x-udisks-auth", widget, data->auth_checkbutton, FALSE, FALSE);
   g_object_thaw_notify (G_OBJECT (data->options_entry));
 
   can_apply = FALSE;
-  if (configured != ui_configured)
+  if (g_strcmp0 (ui_name, name) != 0 ||
+      g_strcmp0 (ui_options, options) != 0 ||
+      g_strcmp0 (ui_passphrase_contents, passphrase_contents) != 0)
     {
       can_apply = TRUE;
     }
-  else if (ui_configured)
-    {
-      if (g_strcmp0 (ui_name, name) != 0 ||
-          g_strcmp0 (ui_options, options) != 0 ||
-          g_strcmp0 (ui_passphrase_contents, passphrase_contents) != 0)
-        {
-          can_apply = TRUE;
-        }
-    }
-
   gtk_dialog_set_response_sensitive (GTK_DIALOG (data->dialog),
                                      GTK_RESPONSE_APPLY,
                                      can_apply);
@@ -215,10 +203,9 @@ crypttab_dialog_present (CrypttabDialogData *data)
       options = "nofail";
       /* propose noauto if the media is removable - otherwise e.g. systemd will time out at boot */
       if (data->drive != NULL && udisks_drive_get_removable (data->drive))
-        options = "noauto";
+        options = "nofail,noauto";
       passphrase_contents = "";
     }
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->configure_checkbutton), configured);
   gtk_entry_set_text (GTK_ENTRY (data->name_entry), name);
   gtk_entry_set_text (GTK_ENTRY (data->options_entry), options);
   gtk_entry_set_text (GTK_ENTRY (data->passphrase_entry), passphrase_contents);
@@ -229,21 +216,11 @@ crypttab_dialog_present (CrypttabDialogData *data)
                           "visibility",
                           G_BINDING_SYNC_CREATE);
 
-  g_object_bind_property (data->configure_checkbutton,
-                          "active",
-                          data->grid,
-                          "sensitive",
-                          G_BINDING_SYNC_CREATE);
-
-  g_signal_connect (data->configure_checkbutton,
-                    "notify::active", G_CALLBACK (on_property_changed), data);
   g_signal_connect (data->name_entry,
                     "notify::text", G_CALLBACK (on_property_changed), data);
   g_signal_connect (data->options_entry,
                     "notify::text", G_CALLBACK (on_property_changed), data);
-  g_signal_connect (data->noauto_checkbutton,
-                    "notify::active", G_CALLBACK (on_property_changed), data);
-  g_signal_connect (data->nofail_checkbutton,
+  g_signal_connect (data->neg_noauto_checkbutton,
                     "notify::active", G_CALLBACK (on_property_changed), data);
   g_signal_connect (data->auth_checkbutton,
                     "notify::active", G_CALLBACK (on_property_changed), data);
@@ -252,31 +229,51 @@ crypttab_dialog_present (CrypttabDialogData *data)
 
   gtk_widget_show_all (data->dialog);
 
+  /* Show "Reset" button only if already configured */
+  if (!configured)
+    gtk_widget_hide (data->reset_button);
+
   update (data, NULL);
 
   response = gtk_dialog_run (GTK_DIALOG (data->dialog));
 
-  if (response == GTK_RESPONSE_APPLY)
+  if (response == 1) /* application-defined for "crypttab-button-reset" */
+    {
+      GError *error;
+
+      error = NULL;
+      if (!udisks_block_call_remove_configuration_item_sync (data->block,
+                                                             g_variant_new ("(s@a{sv})", "crypttab",
+                                                                            data->orig_crypttab_entry),
+                                                             g_variant_new ("a{sv}", NULL), /* options */
+                                                             NULL, /* GCancellable */
+                                                             &error))
+        {
+          gdu_window_show_error (data->window,
+                                 _("Error removing /etc/crypttab entry"),
+                                 error);
+          g_error_free (error);
+          goto out;
+        }
+    }
+  else if (response == GTK_RESPONSE_APPLY)
     {
-      gboolean ui_configured;
       const gchar *ui_name;
       const gchar *ui_options;
       const gchar *ui_passphrase_contents;
       const gchar *old_passphrase_path;
       GError *error;
-      GVariant *old_item;
-      GVariant *new_item;
+      GVariant *old_item = NULL;
+      GVariant *new_item = NULL;
+      GVariantBuilder builder;
+      gchar *s;
 
-      ui_configured = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->configure_checkbutton));
       ui_name = gtk_entry_get_text (GTK_ENTRY (data->name_entry));
       ui_options = gtk_entry_get_text (GTK_ENTRY (data->options_entry));
       ui_passphrase_contents = gtk_entry_get_text (GTK_ENTRY (data->passphrase_entry));
 
       gtk_widget_hide (data->dialog);
 
-      old_item = NULL;
-      new_item = NULL;
-
       old_passphrase_path = NULL;
       if (data->orig_crypttab_entry != NULL)
         {
@@ -291,63 +288,40 @@ crypttab_dialog_present (CrypttabDialogData *data)
                                     data->orig_crypttab_entry);
         }
 
-      if (ui_configured)
+      g_variant_builder_init (&builder, G_VARIANT_TYPE_VARDICT);
+      s = g_strdup_printf ("UUID=%s", udisks_block_get_id_uuid (data->block));
+      g_variant_builder_add (&builder, "{sv}", "device", g_variant_new_bytestring (s));
+      g_free (s);
+      g_variant_builder_add (&builder, "{sv}", "name", g_variant_new_bytestring (ui_name));
+      g_variant_builder_add (&builder, "{sv}", "options", g_variant_new_bytestring (ui_options));
+      if (strlen (ui_passphrase_contents) > 0)
         {
-          GVariantBuilder builder;
-          gchar *s;
-          g_variant_builder_init (&builder, G_VARIANT_TYPE_VARDICT);
-          s = g_strdup_printf ("UUID=%s", udisks_block_get_id_uuid (data->block));
-          g_variant_builder_add (&builder, "{sv}", "device", g_variant_new_bytestring (s));
-          g_free (s);
-          g_variant_builder_add (&builder, "{sv}", "name", g_variant_new_bytestring (ui_name));
-          g_variant_builder_add (&builder, "{sv}", "options", g_variant_new_bytestring (ui_options));
-          if (strlen (ui_passphrase_contents) > 0)
+          /* use old/existing passphrase file, if available */
+          if (old_passphrase_path != NULL)
             {
-              /* use old/existing passphrase file, if available */
-              if (old_passphrase_path != NULL)
-                {
-                  g_variant_builder_add (&builder, "{sv}", "passphrase-path",
-                                         g_variant_new_bytestring (old_passphrase_path));
-                }
-              else
-                {
-                  /* otherwise fall back to the requested name */
-                  s = g_strdup_printf ("/etc/luks-keys/%s", ui_name);
-                  g_variant_builder_add (&builder, "{sv}", "passphrase-path", g_variant_new_bytestring (s));
-                  g_free (s);
-                }
-              g_variant_builder_add (&builder, "{sv}", "passphrase-contents",
-                                     g_variant_new_bytestring (ui_passphrase_contents));
-
+              g_variant_builder_add (&builder, "{sv}", "passphrase-path",
+                                     g_variant_new_bytestring (old_passphrase_path));
             }
           else
             {
-              g_variant_builder_add (&builder, "{sv}", "passphrase-path",
-                                     g_variant_new_bytestring (""));
-              g_variant_builder_add (&builder, "{sv}", "passphrase-contents",
-                                     g_variant_new_bytestring (""));
+              /* otherwise fall back to the requested name */
+              s = g_strdup_printf ("/etc/luks-keys/%s", ui_name);
+              g_variant_builder_add (&builder, "{sv}", "passphrase-path", g_variant_new_bytestring (s));
+              g_free (s);
             }
-
-          new_item = g_variant_new ("(sa{sv})", "crypttab", &builder);
+          g_variant_builder_add (&builder, "{sv}", "passphrase-contents",
+                                 g_variant_new_bytestring (ui_passphrase_contents));
         }
-
-      if (old_item != NULL && new_item == NULL)
+      else
         {
-          error = NULL;
-          if (!udisks_block_call_remove_configuration_item_sync (data->block,
-                                                                 old_item,
-                                                                 g_variant_new ("a{sv}", NULL), /* options */
-                                                                 NULL, /* GCancellable */
-                                                                 &error))
-            {
-              gdu_window_show_error (data->window,
-                                     _("Error removing /etc/crypttab entry"),
-                                     error);
-              g_error_free (error);
-              goto out;
-            }
+          g_variant_builder_add (&builder, "{sv}", "passphrase-path",
+                                 g_variant_new_bytestring (""));
+          g_variant_builder_add (&builder, "{sv}", "passphrase-contents",
+                                 g_variant_new_bytestring (""));
         }
-      else if (old_item == NULL && new_item != NULL)
+      new_item = g_variant_new ("(sa{sv})", "crypttab", &builder);
+
+      if (old_item == NULL && new_item != NULL)
         {
           error = NULL;
           if (!udisks_block_call_add_configuration_item_sync (data->block,
@@ -483,12 +457,11 @@ gdu_crypttab_dialog_show (GduWindow    *window,
 
   data->dialog = dialog;
   data->infobar_vbox = GTK_WIDGET (gtk_builder_get_object (data->builder, "infobar-vbox"));
-  data->configure_checkbutton = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-configure-checkbutton"));
+  data->reset_button = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-reset-button"));
   data->grid = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-grid"));
   data->name_entry = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-name-entry"));
   data->options_entry = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-options-entry"));
-  data->noauto_checkbutton = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-noauto-checkbutton"));
-  data->nofail_checkbutton = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-nofail-checkbutton"));
+  data->neg_noauto_checkbutton = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-neg-noauto-checkbutton"));
   data->auth_checkbutton = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-auth-checkbutton"));
   data->passphrase_label = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-passphrase-label"));
   data->passphrase_entry = GTK_WIDGET (gtk_builder_get_object (data->builder, "crypttab-passphrase-entry"));
